/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react';
import { apiUrl } from '../../../../env';
import { withStyles } from '@material-ui/core/styles';
import TableBody from '@material-ui/core/TableBody';
import TableCell from '@material-ui/core/TableCell';
import TableRow from '@material-ui/core/TableRow';
import IconButton from '@material-ui/core/IconButton';
import VisibilityIcon from '@material-ui/icons/Visibility';
import TableData from '../../../Components/Components/Table';
import DataCard from '../../../Components/Components/DataCard';

const StyledTableCell = withStyles((theme) => ({
    head: {
        backgroundColor: theme.palette.common.black,
        color: theme.palette.common.white,
    },
    body: {
        fontSize: 14,
    },
}))(TableCell);

const StyledTableRow = withStyles((theme) => ({
    root: {
        '&:nth-of-type(odd)': {
            backgroundColor: theme.palette.action.hover,
        },
    },
}))(TableRow);


const Institutions = () => {

    const [error, setError] = useState(null); //Necessary to consult the API, catch errors
    const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete 
    const [items, setItems] = useState([]); //Necessary to consult the API, data
    const productionRoute = 'institutions?filter=%7B%7D&page=0&range=%5B0%2C9%5D&results_per_page=10&sort=%5B"id"%2C"DESC"%5D';

    const [data, setData] = useState([]); // Data that will be used to display the content of the row in full screen, when its clicked
    const [viewData, setViewData] = useState(false); //Controlls the state, if someone wants to see the data

    useEffect(() => {
        fetch(apiUrl + '/' + productionRoute)
            .then(res => res.json())
            .then(
                (result) => {
                    setIsLoaded(true);
                    setItems(result);
                },
                (error) => {
                    setIsLoaded(true);
                    setError(error);
                }
            )
    }, []);

    if (error) {
        return <div>Error: {error.message}</div>;
    } else if (!isLoaded) {
        return <div>Loading...</div>;
    } else {

        const topTable = ['ID', 'Nome', 'Descrição', 'Cidade', 'País', 'Visualizar']

        // i = index of the array of the table
        const viewDataHandler = (i) => {
            const item = { ...items[i] };
            const infoArr = [
                {
                    subTitle: "ID",
                    prop: item.id,
                },
                {
                    subTitle: "Nome",
                    prop: item.name,
                },
                {
                    subTitle: "Descrição",
                    prop: item.description,
                },
                {
                    subTitle: "Endereço",
                    prop: item.address,
                },
                {
                    subTitle: "Cidade",
                    prop: item.city,
                },
                {
                    subTitle: "País",
                    prop: item.country,
                }, 
            ] 
            setData(infoArr);
            setViewData(!viewData)
        };


        return ( 
            !viewData ? 
            <TableData top={topTable}>
                <TableBody>
                    {items.map((row, index) => (
                        index === 0 ? null :
                            <StyledTableRow key={index}>
                                <StyledTableCell component="th" scope="row">{row.id}</StyledTableCell>
                                <StyledTableCell align="right">{row.name}</StyledTableCell>
                                <StyledTableCell align="right">{row.description}</StyledTableCell>
                                <StyledTableCell align="right">{row.city}</StyledTableCell>
                                <StyledTableCell align="right">{row.country}</StyledTableCell>
                                <StyledTableCell align="right">
                                    <IconButton onClick={() => viewDataHandler(index)}>
                                        <VisibilityIcon style={{ fill: '#8A2BE2' }} />
                                    </IconButton>
                                </StyledTableCell>
                            </StyledTableRow>
                    ))}
                </TableBody>
            </TableData> :  
            <DataCard data={data} viewData={() => setViewData(!viewData)}/>
        );
    }
}

export default Institutions;